"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useLanguageLocale = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactI18next = require("react-i18next");

var DateTimeFormatter = _interopRequireWildcard(require("../lib/date-time-formatter"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @packageDocumentation
 * @module Hooks
 * @internal
 */
const useLanguageLocale = () => {
  const {
    t,
    i18n
  } = (0, _reactI18next.useTranslation)();

  const tFunctionWithNoDataDefault = _react.default.useCallback((key, options) => {
    if (typeof options === 'object' && options.count === undefined) {
      // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
      return t(`${key}_noData`, {
        defaultValue: t(key, options),
        ...options
      });
    }

    return t(key, options);
  }, [t]);

  return _react.default.useMemo(() => ({
    t: tFunctionWithNoDataDefault,
    formatDateTime: dateTime => DateTimeFormatter.formatDateTime(dateTime, i18n.language),
    formatMonthLong: dateTime => DateTimeFormatter.formatMonthLong(dateTime, i18n.language),
    formatDate: dateTime => DateTimeFormatter.formatDate(dateTime, i18n.language),
    formatDateShort: dateTime => DateTimeFormatter.formatDateShort(dateTime, i18n.language),
    formatTime: dateTime => DateTimeFormatter.formatTime(dateTime, i18n.language),
    formatTimeShort: dateTime => DateTimeFormatter.formatTimeShort(dateTime, i18n.language),
    timeSince: dateTime => DateTimeFormatter.timeSince(dateTime)
  }), [tFunctionWithNoDataDefault, i18n]);
};

exports.useLanguageLocale = useLanguageLocale;
//# sourceMappingURL=language-locale-hooks.js.map