"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Clock = void 0;

var _dateFns = require("date-fns");

let timeTravelOffset = 0;
let frozenTime;

const internalNow = () => {
  if (frozenTime) {
    return frozenTime;
  }

  return (0, _dateFns.subMilliseconds)(new Date(), timeTravelOffset);
};

const now = () => {
  return internalNow();
};

const assertInTest = () => {
  if (process.env.NODE_ENV !== 'test') {
    throw new Error('Time travel is only allowed in tests!');
  }
};

const timeTravel = async time => {
  assertInTest();
  timeTravelOffset = (0, _dateFns.differenceInMilliseconds)(new Date(), typeof time === 'string' ? new Date(time) : time);
  frozenTime = undefined;
};

const restoreTime = async () => {
  assertInTest();
  timeTravelOffset = 0;
  frozenTime = undefined;
};

const freezeTime = async time => {
  assertInTest();

  if (time) {
    await timeTravel(time);
  }

  frozenTime = internalNow();
};

const unfreezeTime = async () => {
  assertInTest();
  frozenTime = undefined;
};

const Clock = {
  now,
  Testing: {
    timeTravel,
    restoreTime,
    freezeTime,
    unfreezeTime
  }
};
exports.Clock = Clock;
//# sourceMappingURL=clock.js.map